OSSP CVS Repository

ossp - Check-in [1256]
Not logged in
[Honeypot]  [Browse]  [Home]  [Login]  [Reports
[Search]  [Ticket]  [Timeline
  [Patchset]  [Tagging/Branching

Check-in Number: 1256
Date: 2001-Nov-05 21:39:35 (local)
2001-Nov-05 20:39:35 (UTC)
User:rse
Branch:
Comment: Seems like my long years of programming in assembly language still have an impact on my thinking. Change "nop" (assembly mnemonic) to "noop" (english abbreviation) in the name of our no-operation channel. Thanks to Michael for catching this.
Tickets:
Inspections:
Files:
ossp-pkg/l2/Makefile.in      1.28 -> 1.29     14 inserted, 13 deleted
ossp-pkg/l2/l2.h.in      1.16 -> 1.17     1 inserted, 1 deleted
ossp-pkg/l2/l2_ch_noop.c      added-> 1.1
ossp-pkg/l2/l2_ch_nop.c      1.1->removed
ossp-pkg/l2/l2_test.c      1.39 -> 1.40     3 inserted, 3 deleted

ossp-pkg/l2/Makefile.in 1.28 -> 1.29

--- Makefile.in  2001/11/04 14:08:24     1.28
+++ Makefile.in  2001/11/05 20:39:35     1.29
@@ -65,7 +65,7 @@
 OBJS = \
     l2_env.lo \
     l2_channel.lo \
-    l2_ch_nop.lo \
+    l2_ch_noop.lo \
     l2_ch_fd.lo \
     l2_ch_file.lo \
     l2_ch_pipe.lo \
@@ -89,7 +89,7 @@
 SRCS = \
     l2_env.c \
     l2_channel.c \
-    l2_ch_nop.c \
+    l2_ch_noop.c \
     l2_ch_fd.c \
     l2_ch_file.c \
     l2_ch_pipe.c \
@@ -298,23 +298,24 @@
 $(OBJS): Makefile
 
 #   AUTOMATICALLY GENERATED DEPENDENCY LIST - DO NOT EDIT
-l2_env.o: l2_env.c l2.h l2_p.h l2_config.h l2_ut_pcre.h l2_ut_sa.h
-l2_channel.o: l2_channel.c l2.h l2_p.h l2_config.h l2_ut_pcre.h l2_ut_sa.h
+l2_env.o: l2_env.c l2_p.h l2.h l2_config.h l2_ut_format.h l2_ut_pcre.h l2_ut_sa.h
+l2_channel.o: l2_channel.c l2_p.h l2.h l2_config.h l2_ut_format.h l2_ut_pcre.h l2_ut_sa.h
+l2_ch_noop.o: l2_ch_noop.c l2.h
 l2_ch_fd.o: l2_ch_fd.c l2.h
 l2_ch_file.o: l2_ch_file.c l2.h
-l2_ch_pipe.o: l2_ch_pipe.c l2.h l2_p.h l2_config.h l2_ut_pcre.h l2_ut_sa.h
-l2_ch_syslog.o: l2_ch_syslog.c l2.h l2_p.h l2_config.h l2_ut_pcre.h l2_ut_sa.h
-l2_ch_socket.o: l2_ch_socket.c l2.h l2_p.h l2_config.h l2_ut_pcre.h l2_ut_sa.h
-l2_ch_irc.o: l2_ch_irc.c l2.h l2_p.h l2_config.h l2_ut_pcre.h l2_ut_sa.h
-l2_ch_smtp.o: l2_ch_smtp.c l2.h l2_p.h l2_config.h l2_ut_pcre.h l2_ut_sa.h
+l2_ch_pipe.o: l2_ch_pipe.c l2.h l2_p.h l2_config.h l2_ut_format.h l2_ut_pcre.h l2_ut_sa.h
+l2_ch_syslog.o: l2_ch_syslog.c l2.h l2_p.h l2_config.h l2_ut_format.h l2_ut_pcre.h l2_ut_sa.h
+l2_ch_socket.o: l2_ch_socket.c l2.h l2_p.h l2_config.h l2_ut_format.h l2_ut_pcre.h l2_ut_sa.h
+l2_ch_irc.o: l2_ch_irc.c l2.h l2_p.h l2_config.h l2_ut_format.h l2_ut_pcre.h l2_ut_sa.h
+l2_ch_smtp.o: l2_ch_smtp.c l2.h l2_p.h l2_config.h l2_ut_format.h l2_ut_pcre.h l2_ut_sa.h
 l2_ch_null.o: l2_ch_null.c l2.h
 l2_ch_filter.o: l2_ch_filter.c l2.h l2_ut_pcre.h
 l2_ch_prefix.o: l2_ch_prefix.c l2.h
-l2_ch_buffer.o: l2_ch_buffer.c l2.h l2_p.h l2_config.h l2_ut_pcre.h l2_ut_sa.h
-l2_ut_format.o: l2_ut_format.c l2.h l2_p.h l2_config.h l2_ut_pcre.h l2_ut_sa.h
-l2_ut_param.o: l2_ut_param.c l2.h l2_p.h l2_config.h l2_ut_pcre.h l2_ut_sa.h
+l2_ch_buffer.o: l2_ch_buffer.c l2.h l2_p.h l2_config.h l2_ut_format.h l2_ut_pcre.h l2_ut_sa.h
+l2_ut_format.o: l2_ut_format.c l2_ut_format.h
+l2_ut_param.o: l2_ut_param.c l2.h l2_p.h l2_config.h l2_ut_format.h l2_ut_pcre.h l2_ut_sa.h
 l2_ut_pcre.o: l2_ut_pcre.c l2_ut_pcre.h l2_ut_pcre.tab
-l2_ut_level.o: l2_ut_level.c l2.h l2_p.h l2_config.h l2_ut_pcre.h l2_ut_sa.h
+l2_ut_level.o: l2_ut_level.c l2.h l2_p.h l2_config.h l2_ut_format.h l2_ut_pcre.h l2_ut_sa.h
 l2_ut_fmtcb.o: l2_ut_fmtcb.c l2.h
 l2_ut_sa.o: l2_ut_sa.c l2_config.h l2_ut_sa.h
 l2_version.o: l2_version.c l2_version.c


ossp-pkg/l2/l2.h.in 1.16 -> 1.17

--- l2.h.in      2001/11/04 14:08:24     1.16
+++ l2.h.in      2001/11/05 20:39:35     1.17
@@ -200,7 +200,7 @@
 extern l2_handler_t l2_handler_smtp;
 
 /* list of shipped (filter) channel handlers */
-extern l2_handler_t l2_handler_nop;
+extern l2_handler_t l2_handler_noop;
 extern l2_handler_t l2_handler_filter;
 extern l2_handler_t l2_handler_prefix;
 extern l2_handler_t l2_handler_buffer;


ossp-pkg/l2/l2_ch_noop.c -> 1.1

*** /dev/null    Wed Apr 24 09:02:10 2024
--- -    Wed Apr 24 09:02:41 2024
***************
*** 0 ****
--- 1,42 ----
+ /*
+ **  L2 - OSSP Logging Library
+ **  Copyright (c) 2001 The OSSP Project (http://www.ossp.org/)
+ **  Copyright (c) 2001 Cable & Wireless Deutschland (http://www.cw.com/de/)
+ **
+ **  This file is part of OSSP L2, a flexible logging library which
+ **  can be found at http://www.ossp.org/pkg/l2/.
+ **
+ **  Permission to use, copy, modify, and distribute this software for
+ **  any purpose with or without fee is hereby granted, provided that
+ **  the above copyright notice and this permission notice appear in all
+ **  copies.
+ **
+ **  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
+ **  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
+ **  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
+ **  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
+ **  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+ **  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+ **  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
+ **  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
+ **  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
+ **  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
+ **  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+ **  SUCH DAMAGE.
+ **
+ **  l2_ch_noop.c: no-operation channel implementation
+ */
+ 
+ #include "l2.h"
+ 
+ l2_handler_t l2_handler_noop = {
+     L2_CHANNEL_FILTER,
+     NULL,
+     NULL,
+     NULL,
+     NULL,
+     NULL,
+     NULL,
+     NULL
+ };
+ 


ossp-pkg/l2/l2_ch_nop.c 1.1 -> 1.2



ossp-pkg/l2/l2_test.c 1.39 -> 1.40

--- l2_test.c    2001/11/04 14:08:24     1.39
+++ l2_test.c    2001/11/05 20:39:35     1.40
@@ -74,9 +74,9 @@
     if (l2_env_formatter(env, 'S', l2_util_fmt_dump, NULL) != L2_OK)
         die("failed to configure formatter for %%S");
 
-    /* create nop channel */
-    if ((l2_channel_create(&ch, env, &l2_handler_nop)) != L2_OK)
-        die("failed to create nop channel");
+    /* create noop channel */
+    if ((l2_channel_create(&ch, env, &l2_handler_noop)) != L2_OK)
+        die("failed to create noop channel");
 
     /* create prefix channel */
     if ((l2_channel_create(&chPrefix, env, &l2_handler_prefix)) != L2_OK)

CVSTrac 2.0.1